@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Bakerloo;
 
-$Map::Tube::London::Line::Bakerloo::VERSION = '0.23';
+$Map::Tube::London::Line::Bakerloo::VERSION = '0.24';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::London::Line::Bakerloo - London Tube Map Bakerloo Line stations.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =head1 DESCRIPTION
 
@@ -52,10 +52,13 @@ London Tube Map Bakerloo Line stations.
 
 =item * The station "Oxford Circus" is also part of L<Central Line|Map::Tube::London::Line::Central>.
 
-=item * The station "Paddington" is also part of L<Circle Line|Map::Tube::London::Line::Circle>.
+=item * The station "Paddington" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+        | <Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
 
 =item * The station "Embankment" is also part of L<District Line|Map::Tube::London::Line::District>.
 
+=item * The station "Baker Street" is also part of Jubilee Line | Metropolitan Line.
+
 =back
 
 =head1 AUTHOR
