@@ -1,6 +1,6 @@
 package Map::Tube::London::Line::Central;
 
-$Map::Tube::London::Line::Central::VERSION = '0.23';
+$Map::Tube::London::Line::Central::VERSION = '0.24';
 
 =head1 NAME
 
@@ -8,7 +8,7 @@ Map::Tube::London::Line::Central - London Tube Map Central Line stations.
 
 =head1 VERSION
 
-Version 0.23
+Version 0.24
 
 =head1 DESCRIPTION
 
@@ -80,6 +80,9 @@ London Tube Map Central Line stations.
 
 =item * The station "Notting Hill Gate" is also part of L<District Line|Map::Tube::London::Line::District>.
 
+=item * The station "Liverpool Street" is also part of L<Circle Line|Map::Tube::London::Line::Circle>
+        | L<Hammersmith & City Line|Map::Tube::London::Line::HammersmithCity>.
+
 =back
 
 =head1 AUTHOR
